<?php

function view_dashboard_get_petty_cash_i_owe_yous_details($from_date, $to_date, $approval_status_array=null, $not_ap_st_array=null) {
    return dashboard_get_petty_cash_i_owe_yous_details($from_date, $to_date, $approval_status_array, $not_ap_st_array);
}

function view_dashboard_get_petty_cash_i_owe_yous_expenses_entered_details($from_date, $to_date) {
    return dashboard_get_petty_cash_i_owe_yous_expenses_entered_details($from_date, $to_date);
}

function view_dashboard_get_petty_cash_i_owe_yous_completed_details($from_date, $to_date) {
    return dashboard_get_petty_cash_i_owe_yous_completed_details($from_date, $to_date);
}

function view_dashboard_get_petty_cash_expenses_details($from_date, $to_date, $approval_status_array=null, $not_ap_st_array=null) {
    return dashboard_get_petty_cash_expenses_details($from_date, $to_date, $approval_status_array, $not_ap_st_array);
}

function view_dashboard_get_petty_cash_expenses_completed_details($from_date, $to_date) {
    return dashboard_get_petty_cash_expenses_completed_details($from_date, $to_date);
}

function view_dashboard_get_petty_cash_expense_batches_details($from_date, $to_date, $approval_status_array=null, $not_ap_st_array=null) {
    return dashboard_get_petty_cash_expense_batches_details($from_date, $to_date, $approval_status_array, $not_ap_st_array);
}

function view_dashboard_get_petty_cash_expense_batches_checked_details($from_date, $to_date) {
    return dashboard_get_petty_cash_expense_batches_checked_details($from_date, $to_date);
}

function view_dashboard_get_petty_cash_expense_batches_completed_details($from_date, $to_date) {
    return dashboard_get_petty_cash_expense_batches_completed_details($from_date, $to_date);
}

?>